@@ -167,7 +167,7 @@ class LibraryManager(Singleton):
                 SGE_ARCH = p.read().rstrip()
             finally:
                 p.close()
-            lib_dir = SGE_ROOT + '/lib/' + SGE_ARCH
+            lib_dir = SGE_ROOT + '/drmaa/lib/' + SGE_ARCH
             cls.logger.debug('Looking for DRMAA2 library under %s' % lib_dir)
             lib_paths = glob.glob(lib_dir + '/libdrmaa2.so')
             if not lib_paths:
